@@ -1,5 +1,9 @@
 /* 
  * $Log: ypbind.c,v $
+ * Revision 1.4  1995/11/15 10:06:25  swen
+ * Added SYSV-IPC (from Michael Rausch <mrausch@ernie.mi.uni-koeln.de>)
+ * Make mmap (not MAP_ANON) work again with latest kernels.
+ *
  * Revision 1.3  1995/10/13 11:51:58  swen
  * Added -v flag for version info.
  *
@@ -15,7 +19,7 @@
  *
  */
 
-static char rcsid[] = "$Id: ypbind.c,v 1.3 1995/10/13 11:51:58 swen Exp $" ;
+static char rcsid[] = "$Id: ypbind.c,v 1.4 1995/11/15 10:06:25 swen Exp $" ;
 
 #include <sys/types.h>
 #include <sys/mman.h>
@@ -53,9 +57,7 @@ extern int use_broadcast;
 SVCXPRT *udptransp, *tcptransp;
 domainname mydomain;
 int ypsetmode = YPSET_NO;
-struct binding *ypbindlist;
 pid_t childpid;
-int lockfd;
 int broken_server;
 volatile int debug;
 
@@ -96,7 +98,7 @@ ypbindproc_domain_2_svc(domainname arg1, struct svc_req *rqstp)
                   inet_ntoa(ypdb->server_addr), ntohs(ypdb->server_port));
     }
   
-  un_lock_binding();
+  un_lock_read_binding();
   return &result;
 }
 
@@ -266,23 +268,7 @@ main(int argc, char *argv[])
   if(0 != atexit(terminate))
     log_quit("Could not install exit handler");
 
-  lockfd = open_lockfile();
-#if MMAP_SHARED_OK  
-  ypbindlist = (struct binding *) mmap(0, sizeof(struct binding) * _MAXDOMAIN,
-                                       (PROT_READ | PROT_WRITE), 
-#if MMAP_ANON_SHARED_OK
-                                       (MAP_ANON | MAP_SHARED), -1, 0);
-#else  
-                                       MAP_SHARED, lockfd, 0);
-#endif /* MMAP_ANON_SHARED_OK */
-  if ((caddr_t) -1 == (caddr_t) ypbindlist)
-    log_sys("cannot create shared region");
-#else
-  ypbindlist = (struct binding *) calloc(_MAXDOMAIN, sizeof(struct binding));
-  if (NULL == ypbindlist)
-    log_sys("cannot create shared region");
-  writen(lockfd, ypbindlist, sizeof(struct binding) * _MAXDOMAIN);
-#endif /* MMAP_SHARED_OK */
+  init_master_slave_communication();
   
       /* no check for return code here */
   pmap_unset(YPBINDPROG, YPBINDVERS);
@@ -376,6 +362,9 @@ sighandler(int sig)
       if ( 0 != sigaction(sig, &sact, NULL))
         log_quit("Could not uninstall signal handler for signal %d.", sig);
       kill(childpid, sig);
+#if USE_IPC
+      terminate_master_slave_communication();
+#endif
       unlink(_PATH_YPPIDFILE);
       raise(sig);
       exit(0); /* just in case */
@@ -388,6 +377,9 @@ terminate(void)
   unlink(_PATH_YPPIDFILE);
   if (0 != childpid)
     kill(childpid, SIGTERM);
+#if USE_IPC
+  terminate_master_slave_communication();
+#endif
   pmap_unset(YPBINDPROG, YPBINDVERS);
 }
 
@@ -450,6 +442,3 @@ create_pidfile(void)
   writen(fd, pbuf, strlen(pbuf));
   return;
 }
-
-  
-  
