@@ -1,6 +1,10 @@
 /*
  * $Log: ypbind.h,v $
- * Revision 1.1  1995/07/25 14:28:02  swen
+ * Revision 1.2  1995/11/15 10:06:31  swen
+ * Added SYSV-IPC (from Michael Rausch <mrausch@ernie.mi.uni-koeln.de>)
+ * Make mmap (not MAP_ANON) work again with latest kernels.
+ *
+ * Revision 1.1  1995/07/25  14:28:02  swen
  * ypbind version 2.0.
  *
  * Revision 2.4  1995/01/24  12:24:32  swen
@@ -17,15 +21,22 @@
 #endif
 #define _PATH_YPPIDFILE _PATH_VARRUN"ypbind.pid"
 #define _MAXDOMAIN  8
-#define REBIND_INTERVAL 300 /* rebind every 5 minutes */
-#define PING_INTERVAL     5 /* check binding every 5 seconds */
+#define REBIND_INTERVAL 1800 /* rebind every 30 minutes */
+#define PING_INTERVAL     60 /* check binding every minute */
 #define YPSET_NO	0
 #define YPSET_LOCAL	1
 #define YPSET_ALL	2
 
+#define USE_IPC 1		  /* use SysV IPC for sharing the bindings */
+
 #define MMAP_SHARED_OK 0          /* does shared mapping of files work? */
                                   /* (it does in 1.3.12                 */
-#define MMAP_SHARED_ANON_OK 0     /* can we share anonymous regions?    */
+#define MMAP_SHARED_ANON_OK 0     /* can we share anonymous regions? (not yet in 1.3.40) */
+
+#if USE_IPC
+#undef MMAP_SHARED_OK
+#define MMAP_SHARED_OK 1	  /* SysV IPC is handled the same way ... */
+#endif
 
 struct binding
 {
@@ -69,8 +80,13 @@ void bindto_server (char *, struct hostent *);
 void ping_server(struct binding *);
 void write_lock_binding(void);
 void read_lock_binding(void);
-void un_lock_binding(void);
+void un_lock_read_binding(void);
+void un_lock_write_binding(void);
 void inststr(char **, int, const char *);
 void init_binding(void);
 void check_binding(void);
 void create_pidfile(void);
+void init_master_slave_communication(void);
+#if USE_IPC
+void terminate_master_slave_communication(void);
+#endif
